@@ -1,11 +1,11 @@
 """
   scenariogeneration
   https://github.com/pyoscx/scenariogeneration
- 
+
   This Source Code Form is subject to the terms of the Mozilla Public
   License, v. 2.0. If a copy of the MPL was not distributed with this
   file, You can obtain one at https://mozilla.org/MPL/2.0/.
- 
+
   Copyright (c) 2022 The scenariogeneration Authors.
 
 """
@@ -18,6 +18,7 @@ from scenariogeneration.helpers import prettify
 from scenariogeneration.xosc.actions import TrafficSignalControllerAction
 from scenariogeneration.xosc.enumerations import ReferenceContext
 from scenariogeneration.xosc.exceptions import NoActionsDefinedError
+from scenariogeneration.xosc.enumerations import _MINOR_VERSION
 
 TD = OSC.TransitionDynamics(OSC.DynamicsShapes.step, OSC.DynamicsDimension.rate, 1.0)
 
@@ -35,24 +36,37 @@ traffic.add_vehicle(OSC.VehicleCategory.bicycle, 0.1)
 env = OSC.Environment("Env_name", tod, weather, rc)
 
 
+@pytest.fixture(autouse=True)
+def reset_version():
+    OSC.enumerations.VersionBase().setVersion(minor=_MINOR_VERSION)
+
+
 @pytest.mark.parametrize(
-    "action",
+    "input",
     [
-        OSC.EnvironmentAction(env),
-        OSC.AddEntityAction("my new thingy", OSC.WorldPosition()),
-        OSC.DeleteEntityAction("my new thingy"),
-        OSC.ParameterAddAction("Myparam", 3),
-        OSC.ParameterSetAction("Myparam", 3),
-        OSC.TrafficSignalStateAction("my signal", "red"),
-        OSC.TrafficSignalControllerAction("Phase", "TSCRef_Name"),
-        OSC.TrafficSourceAction(10, 10, OSC.WorldPosition(), traffic, 100),
-        OSC.TrafficSinkAction(10, OSC.WorldPosition(), traffic, 10),
-        OSC.TrafficSwarmAction(10, 20, 10, 2, 10, "Ego", traffic),
-        OSC.TrafficStopAction("Stop_Action"),
+        [OSC.EnvironmentAction(env), _MINOR_VERSION],
+        [OSC.AddEntityAction("my new thingy", OSC.WorldPosition()), _MINOR_VERSION],
+        [OSC.DeleteEntityAction("my new thingy"), _MINOR_VERSION],
+        [OSC.ParameterAddAction("Myparam", 3), 1],
+        [OSC.ParameterMultiplyAction("Myparam", 3), 1],
+        [OSC.ParameterSetAction("Myparam", 3), 1],
+        [OSC.VariableAddAction("Myparam", 3), _MINOR_VERSION],
+        [OSC.VariableMultiplyAction("Myparam", 3), _MINOR_VERSION],
+        [OSC.VariableSetAction("Myparam", 3), _MINOR_VERSION],
+        [OSC.TrafficSignalStateAction("my signal", "red"), _MINOR_VERSION],
+        [OSC.TrafficSignalControllerAction("Phase", "TSCRef_Name"), _MINOR_VERSION],
+        [
+            OSC.TrafficSourceAction(10, 10, OSC.WorldPosition(), traffic, 100),
+            _MINOR_VERSION,
+        ],
+        [OSC.TrafficSinkAction(10, OSC.WorldPosition(), traffic, 10), _MINOR_VERSION],
+        [OSC.TrafficSwarmAction(10, 20, 10, 2, 10, "Ego", traffic), _MINOR_VERSION],
+        [OSC.TrafficStopAction("Stop_Action"), _MINOR_VERSION],
     ],
 )
-def test_global_action_factory(action):
-
+def test_global_action_factory(input):
+    action = input[0]
+    action.setVersion(minor=input[1])
     factoryoutput = OSC.actions._GlobalActionFactory.parse_globalaction(
         action.get_element()
     )
@@ -112,16 +126,29 @@ ass = OSC.AssignControllerAction(cnt)
         OSC.AssignRouteAction(route),
         OSC.FollowTrajectoryAction(
             traj,
-            OSC.FollowMode.position,
+            OSC.FollowingMode.position,
             reference_domain=ReferenceContext.absolute,
             offset=3,
             scale=4,
         ),
         OSC.AcquirePositionAction(OSC.WorldPosition(1, 1, 0, 0, 0, 0)),
+        OSC.AnimationAction(OSC.VehicleComponentType.doorFrontRight, 1, False, 1),
+        OSC.LightStateAction(
+            OSC.VehicleLightType.brakeLights,
+            OSC.LightMode.on,
+            transition_time=0.1,
+            color=OSC.Color(OSC.ColorType.black, OSC.ColorRGB(0, 0, 0)),
+        ),
+        OSC.SpeedProfileAction(
+            [5, 4, 3],
+            OSC.FollowingMode.follow,
+            [1, 2, 3],
+            OSC.DynamicsConstraints(1, 1, 1),
+            "ego",
+        ),
     ],
 )
 def test_private_action_factory(action):
-
     factoryoutput = OSC.actions._PrivateActionFactory.parse_privateaction(
         action.get_element()
     )
@@ -286,7 +313,6 @@ def test_teleport():
 
 
 def test_assign_route():
-
     route = OSC.Route("myroute")
     route.add_waypoint(OSC.WorldPosition(0, 0, 0, 0, 0, 0), OSC.RouteStrategy.shortest)
     route.add_waypoint(OSC.WorldPosition(1, 1, 0, 0, 0, 0), OSC.RouteStrategy.shortest)
@@ -352,6 +378,15 @@ def test_activate_controller_action():
     prettyprint(aca5)
     aca6 = OSC.ActivateControllerAction.parse(aca5.get_element())
 
+    aca5 = OSC.ActivateControllerAction(True, True, True, True, "controller_name")
+    aca6 = OSC.ActivateControllerAction(True, True, True, True, "controller_name2")
+    assert aca5 != aca6
+    aca7 = OSC.ActivateControllerAction(True, True, True, False, "controller_name")
+    assert aca5 != aca7
+    aca8 = OSC.ActivateControllerAction.parse(aca5.get_element())
+    prettyprint(aca5.get_element())
+    assert aca5 == aca8
+
 
 def test_assign_controller_action():
     prop = OSC.Properties()
@@ -370,7 +405,8 @@ def test_assign_controller_action():
     cnt2 = OSC.Controller("mycontroller", prop2)
 
     aca2 = OSC.AssignControllerAction(cnt)
-    aca3 = OSC.AssignControllerAction(cnt2)
+    aca3 = OSC.AssignControllerAction(cnt2, True, True, True, True)
+    prettyprint(aca3.get_element(), None)
     assert aca == aca2
     assert aca != aca3
 
@@ -413,9 +449,11 @@ def test_override_controller():
 
 def test_visual_action():
     va = OSC.VisibilityAction(True, False, True)
+    va.add_sensor_reference("mysensor")
     prettyprint(va.get_element(), None)
     va2 = OSC.VisibilityAction(True, False, True)
-    va3 = OSC.VisibilityAction(True, False, False)
+    va2.add_sensor_reference("mysensor")
+    va3 = OSC.VisibilityAction(True, False, True)
     assert va == va2
     assert va != va3
 
@@ -425,7 +463,6 @@ def test_visual_action():
 
 
 def test_sync_action():
-
     asa = OSC.SynchronizeAction(
         "Ego",
         OSC.WorldPosition(0, 0, 0, 0, 0, 0),
@@ -472,7 +509,6 @@ def test_sync_action():
 
 
 def test_follow_traj_action_polyline():
-
     positionlist = []
     positionlist.append(OSC.RelativeLanePosition(-3, "Ego", 0, 10))
     positionlist.append(OSC.RelativeLanePosition(-3, "Ego", 0, 10))
@@ -486,7 +522,7 @@ def test_follow_traj_action_polyline():
 
     trajact = OSC.FollowTrajectoryAction(
         traj,
-        OSC.FollowMode.position,
+        OSC.FollowingMode.position,
         reference_domain=ReferenceContext.absolute,
         offset=3,
         scale=4,
@@ -495,7 +531,7 @@ def test_follow_traj_action_polyline():
 
     trajact2 = OSC.FollowTrajectoryAction(
         traj,
-        OSC.FollowMode.position,
+        OSC.FollowingMode.position,
         reference_domain=ReferenceContext.absolute,
         offset=3,
         scale=4,
@@ -503,7 +539,7 @@ def test_follow_traj_action_polyline():
     traj2 = OSC.Trajectory("my_trajectory", True)
     traj2.add_shape(polyline)
 
-    trajact3 = OSC.FollowTrajectoryAction(traj2, OSC.FollowMode.position)
+    trajact3 = OSC.FollowTrajectoryAction(traj2, OSC.FollowingMode.position)
     assert trajact == trajact2
     assert trajact != trajact3
 
@@ -514,6 +550,7 @@ def test_follow_traj_action_polyline():
 
 def testParameterAddActions():
     pa = OSC.ParameterAddAction("Myparam", 3)
+    pa.setVersion(minor=1)
     prettyprint(pa.get_element())
     pa2 = OSC.ParameterAddAction("Myparam", 3)
     pa3 = OSC.ParameterAddAction("Myparam", 2)
@@ -526,6 +563,7 @@ def testParameterAddActions():
 
 def testParameterMultiplyActions():
     pa = OSC.ParameterMultiplyAction("Myparam", 3)
+    pa.setVersion(minor=1)
     prettyprint(pa)
     pa2 = OSC.ParameterMultiplyAction("Myparam", 3)
     pa3 = OSC.ParameterMultiplyAction("Myparam", 2)
@@ -538,6 +576,7 @@ def testParameterMultiplyActions():
 
 def testParameterSetActions():
     pa = OSC.ParameterSetAction("Myparam", 3)
+    pa.setVersion(minor=1)
     prettyprint(pa)
     pa2 = OSC.ParameterSetAction("Myparam", 3)
     pa3 = OSC.ParameterSetAction("Myparam2", 3)
@@ -548,6 +587,42 @@ def testParameterSetActions():
     assert pa == pa4
 
 
+def testVariableAddActions():
+    pa = OSC.VariableAddAction("Myparam", 3)
+    prettyprint(pa.get_element())
+    pa2 = OSC.VariableAddAction("Myparam", 3)
+    pa3 = OSC.VariableAddAction("Myparam", 2)
+    assert pa == pa2
+    assert pa != pa3
+
+    pa4 = OSC.VariableAddAction.parse(pa.get_element())
+    assert pa == pa4
+
+
+def testVariableMultiplyActions():
+    pa = OSC.VariableMultiplyAction("Myparam", 3)
+    prettyprint(pa)
+    pa2 = OSC.VariableMultiplyAction("Myparam", 3)
+    pa3 = OSC.VariableMultiplyAction("Myparam", 2)
+    assert pa == pa2
+    assert pa != pa3
+
+    pa4 = OSC.VariableMultiplyAction.parse(pa.get_element())
+    assert pa == pa4
+
+
+def testVariableSetActions():
+    pa = OSC.VariableSetAction("Myparam", 3)
+    prettyprint(pa)
+    pa2 = OSC.VariableSetAction("Myparam", 3)
+    pa3 = OSC.VariableSetAction("Myparam2", 3)
+    assert pa == pa2
+    assert pa != pa3
+
+    pa4 = OSC.VariableSetAction.parse(pa.get_element())
+    assert pa == pa4
+
+
 def test_trafficsignalstateaction():
     tss = OSC.TrafficSignalStateAction("my signal", "red")
     prettyprint(tss)
@@ -600,7 +675,6 @@ def test_trafficsignalcontrolleraction():
 
 
 def test_trafficsourceaction():
-
     prop = OSC.Properties()
     prop.add_file("mycontrollerfile.xml")
     controller = OSC.Controller("mycontroller", prop)
@@ -632,7 +706,6 @@ def test_trafficsourceaction():
 
 
 def test_trafficsinkaction():
-
     prop = OSC.Properties()
     prop.add_file("mycontrollerfile.xml")
     controller = OSC.Controller("mycontroller", prop)
@@ -660,10 +733,10 @@ def test_trafficsinkaction():
 
 
 def test_trafficswarmaction():
-
     prop = OSC.Properties()
     prop.add_file("mycontrollerfile.xml")
     controller = OSC.Controller("mycontroller", prop)
+    dot = OSC.DirectionOfTravelDistribution(0.5, 0.5)
 
     traffic = OSC.TrafficDefinition("my traffic")
     traffic.add_controller(controller, 0.5)
@@ -678,8 +751,9 @@ def test_trafficswarmaction():
     # prettyprint(swarm_action.get_element())
 
     swarm_action2 = OSC.TrafficSwarmAction(10, 20, 10, 2, 10, "Ego", traffic)
+
     swarm_action3 = OSC.TrafficSwarmAction(
-        10, 20, 10, 2, 10, "Ego", traffic, 10, "Traffic_name"
+        10, 20, 10, 2, 10, "Ego", traffic, OSC.Range(10, 20), "Traffic_name", dot
     )
     prettyprint(swarm_action3.get_element())
 
@@ -753,3 +827,73 @@ def test_userdefinedaction():
     uda3 = OSC.UserDefinedAction.parse(uda.get_element())
     prettyprint(uda3)
     assert uda3 == uda
+
+
+def test_lightstateaction():
+    lsa = OSC.LightStateAction(
+        OSC.VehicleLightType.brakeLights,
+        OSC.LightMode.on,
+        transition_time=0.1,
+        color=OSC.Color(OSC.ColorType.black, OSC.ColorRGB(0, 0, 0)),
+    )
+    lsa2 = OSC.LightStateAction(
+        OSC.VehicleLightType.brakeLights,
+        OSC.LightMode.on,
+        transition_time=0.1,
+        color=OSC.Color(OSC.ColorType.black, OSC.ColorRGB(0, 0, 0)),
+    )
+    lsa3 = OSC.LightStateAction(
+        OSC.UserDefinedLight("super light"),
+        OSC.LightMode.on,
+        transition_time=0.1,
+        color=OSC.Color(OSC.ColorType.black, OSC.ColorRGB(0, 0, 0)),
+    )
+    prettyprint(lsa)
+    prettyprint(lsa3)
+    assert lsa == lsa2
+    assert lsa != lsa3
+    lsa4 = OSC.LightStateAction.parse(lsa.get_element())
+    assert lsa4 == lsa
+    lsa5 = OSC.LightStateAction.parse(lsa3.get_element())
+    assert lsa5 == lsa3
+
+
+def test_speedprofileaction():
+    spa = OSC.SpeedProfileAction(
+        [5, 4, 3],
+        OSC.FollowingMode.follow,
+        [1, 2, 3],
+        OSC.DynamicsConstraints(1, 1, 1),
+        "ego",
+    )
+    spa2 = OSC.SpeedProfileAction(
+        [5, 4, 3],
+        OSC.FollowingMode.follow,
+        [1, 2, 3],
+        OSC.DynamicsConstraints(1, 1, 1),
+        "ego",
+    )
+    spa3 = OSC.SpeedProfileAction([5, 4, 3], OSC.FollowingMode.follow)
+    prettyprint(spa)
+    prettyprint(spa3)
+    assert spa == spa2
+    assert spa != spa3
+    spa4 = OSC.SpeedProfileAction.parse(spa.get_element())
+    prettyprint(spa4)
+    assert spa == spa4
+
+
+def test_animation_action():
+    aa = OSC.AnimationAction(OSC.VehicleComponentType.doorFrontRight, 1, False, 1)
+
+    prettyprint(aa)
+    aa2 = OSC.AnimationAction(OSC.VehicleComponentType.doorFrontRight, 1, False, 1)
+    aa3 = OSC.AnimationAction(
+        OSC.PedestrianAnimation(OSC.PedestrianMotionType.squatting), 1, False, 1
+    )
+
+    assert aa == aa2
+    assert aa != aa3
+    aa4 = OSC.AnimationAction.parse(aa.get_element())
+    prettyprint(aa4)
+    assert aa == aa4
