@@ -1,11 +1,11 @@
 """
   scenariogeneration
   https://github.com/pyoscx/scenariogeneration
- 
+
   This Source Code Form is subject to the terms of the Mozilla Public
   License, v. 2.0. If a copy of the MPL was not distributed with this
   file, You can obtain one at https://mozilla.org/MPL/2.0/.
- 
+
   Copyright (c) 2022 The scenariogeneration Authors.
 
 """
@@ -39,7 +39,6 @@ def test_road():
 
 
 def test_catalog():
-
     catalog = OSC.Catalog()
     catalog.add_catalog("VehicleCatalog", "Catalogs/VehicleCatalogs")
     catalog.add_catalog("ControllerCatalog", "Catalogs/ControllerCatalogs")
@@ -121,7 +120,8 @@ def test_scenario():
 
     sb = OSC.StoryBoard(init)
     sb.add_story(story)
-
+    variables = OSC.VariableDeclarations()
+    variables.add_variable(OSC.Variable("my_var", OSC.ParameterType.string, "hej"))
     sce = OSC.Scenario(
         "myscenario",
         "Mandolin",
@@ -150,11 +150,12 @@ def test_scenario():
         storyboard=sb,
         roadnetwork=road,
         catalog=catalog,
+        variable_declaration=variables,
     )
 
     assert sce == sce2
     assert sce != sce3
-
+    prettyprint(sce3)
     sce4 = OSC.Scenario.parse(sce.get_element())
     prettyprint(sce4.get_element(), None)
     assert sce == sce4
